@@ -1,4 +1,4 @@
-"""Python package emqxlwm2m"""
+"""A Python interface to the EMQx LwM2M plugin"""
 
 # Module metadata
 __author__ = 'Daniel Andersson'
@@ -8,9 +8,10 @@ __contact__ = __email__
 __copyright__ = 'Copyright (c) 2020 Daniel Andersson'
 __license__ = 'MIT'
 __url__ = 'https://github.com/Penlect/emqxlwm2m'
-__version__ = '0.2.0'
+__version__ = '0.3.2'
 
-# Package
-from .core import LwM2MGateway
-
-__all__ = ['LwM2MGateway']
+from .lwm2m import (
+    ResponseError,
+    NoResponseError,
+    BadPath
+)
